=================================
Electrochemical Dynamics Library
=================================

The electrochemical dynamics library (``eldl``) provides useful
classes and functions for modeling electrochemical dynamics
using the open-source finite-element library |FEniCSx|_.

``eldl`` requires: Python 3.10+.

**PyPI package name**: eldl_

.. toctree::
   :maxdepth: 1
   :hidden:

   Get Started <get_started>
   user_guide/index
   contributing/index
   changelog
   License <license>

.. _eldl: https://pypi.org/project/eldl/
.. |FEniCSx| replace:: `FEniCSx`
.. _FEniCSx: https://fenicsproject.org
